/*
 * Servo + Sensor
 * 
 * An ultrasonic sensor moves two servo motors when it detects an object nearby.
 * 
 * The circuit:
 * - Sensor HC-SR04's echopin attached to 3 and Sensor HC-SR04's triggerpin attached to 2
 * - Servo 1 attached to pin 6
 * - Servo 2 attached to pin 5
 * 
 * created 2021
 * by Héctor Carreras, Juli Font and Clàudia Ros
 * 
 * */

#include <Servo.h>          // include the servo library
Servo myservo1;             // variables for servos
Servo myservo2;

int pos1=0;                 // initial position for every servo
int pos2=0;


#include <HCSR04.h>         // inclue the sensor library

byte triggerPin = 2;        // pinning the HC-SR04 sensor
byte echoPin = 3;

void setup () {
  Serial.begin(9600);       // number of bits read by the sensor
  HCSR04.begin(triggerPin, echoPin);
  myservo1.attach(6);       // the pin where the servo is attached to
  myservo2.attach(5);
}

void loop () {
  double* distances = HCSR04.measureDistanceCm();   // declare the distance value
  
  Serial.print("1: ");
  Serial.print(distances[0]);
  Serial.println(" cm");
  
  Serial.println("---");                            // read the distance detected by the sensor
  delay(250);

// check the sensor distance, if it is smaller than 15 move the servo 90 degrees
  if (distances[0]< 15 ){ 
    pos1=90;
    pos2=90;

    myservo1.write(pos1);       // does what pos1 says
    myservo2.write(pos2);
  }
  // check the sensor distance, if it is bigger than 15 move the servo returns to the original position = 0 degrees
  if(distances[0] > 15){ 
    pos1=0;
    pos2=0;

    myservo1.write(pos1);       // does what pos1 says
    myservo2.write(pos2);
  }
}
